<?php

namespace Drupal\googlereviews\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use \Drupal\googlereviews\GetGoogleData as GetGoogleDataService;

/**
 * Provides a block with Google reviews rating.
 *
 * @Block(
 *   id = "googlereviews_rating",
 *   admin_label = @Translation("Google Reviews Rating"),
 *   category = @Translation("Google Reviews")
 * )
 */
class GoogleRatingBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The Get Google Data service.
   *
   * @var \Drupal\googlereviews\GetGoogleData
   */
  protected $getGoogleData;


  /**
   * @param array $configuration
   * @param string $plugin_id
   * @param mixed $plugin_definition
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, GetGoogleDataService $getGoogleData) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->getGoogleData = $getGoogleData;
  }

  /**
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   * @param array $configuration
   * @param string $plugin_id
   * @param mixed $plugin_definition
   *
   * @return static
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('googlereviews.get_google_data')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $rating = $this->getGoogleData->getGoogleReviews(array('rating', 'user_ratings_total'));

    if(isset($rating)) {
      $renderable = [
        '#attached'=> ['library' => ['googlereviews/googlereviews.rating']],
        '#theme' => 'googlereviews_rating_block',
        '#user_ratings_total' => $rating['user_ratings_total'],
        '#rating' => $rating['rating'],
        '#rating_percentage' => ($rating['rating']/5)*100,
        '#place_id' => $rating['place_id']
      ];

      return $renderable;
    }
  }

}
